@@ -19,9 +19,9 @@ var searchData=
   ['openvdb_5fhas_5fcxx11_16',['OPENVDB_HAS_CXX11',['../Platform_8h.html#ac3004d334cb9a9ac58f68c343220e571',1,'Platform.h']]],
   ['openvdb_5fhoudini_5fapi_17',['OPENVDB_HOUDINI_API',['../Platform_8h.html#a88b26daa45bbdd69d6bb12f9c7bfa3b2',1,'Platform.h']]],
   ['openvdb_5fimath_5fversion_18',['OPENVDB_IMATH_VERSION',['../version_8h_8in.html#a402e2478a133638ddb3b67454b884246',1,'version.h.in']]],
-  ['openvdb_5finstantiate_19',['OPENVDB_INSTANTIATE',['../ExplicitInstantiation_8h.html#ae7babe623b8ad4e7e475f538816f8050',1,'OPENVDB_INSTANTIATE():&#160;ExplicitInstantiation.h'],['../version_8h_8in.html#ae7babe623b8ad4e7e475f538816f8050',1,'OPENVDB_INSTANTIATE():&#160;version.h.in']]],
-  ['openvdb_5finstantiate_5fclass_20',['OPENVDB_INSTANTIATE_CLASS',['../version_8h_8in.html#a442b05a4442dd035a1c03b9d940265df',1,'OPENVDB_INSTANTIATE_CLASS():&#160;version.h.in'],['../ExplicitInstantiation_8h.html#a442b05a4442dd035a1c03b9d940265df',1,'OPENVDB_INSTANTIATE_CLASS():&#160;ExplicitInstantiation.h']]],
-  ['openvdb_5finstantiate_5fstruct_21',['OPENVDB_INSTANTIATE_STRUCT',['../version_8h_8in.html#a16997c6054e446cc8ed613c9b027522d',1,'OPENVDB_INSTANTIATE_STRUCT():&#160;version.h.in'],['../ExplicitInstantiation_8h.html#a16997c6054e446cc8ed613c9b027522d',1,'OPENVDB_INSTANTIATE_STRUCT():&#160;ExplicitInstantiation.h']]],
+  ['openvdb_5finstantiate_19',['openvdb_instantiate',['../ExplicitInstantiation_8h.html#ae7babe623b8ad4e7e475f538816f8050',1,'OPENVDB_INSTANTIATE:&#160;ExplicitInstantiation.h'],['../version_8h_8in.html#ae7babe623b8ad4e7e475f538816f8050',1,'OPENVDB_INSTANTIATE:&#160;version.h.in']]],
+  ['openvdb_5finstantiate_5fclass_20',['openvdb_instantiate_class',['../version_8h_8in.html#a442b05a4442dd035a1c03b9d940265df',1,'OPENVDB_INSTANTIATE_CLASS:&#160;version.h.in'],['../ExplicitInstantiation_8h.html#a442b05a4442dd035a1c03b9d940265df',1,'OPENVDB_INSTANTIATE_CLASS:&#160;ExplicitInstantiation.h']]],
+  ['openvdb_5finstantiate_5fstruct_21',['openvdb_instantiate_struct',['../version_8h_8in.html#a16997c6054e446cc8ed613c9b027522d',1,'OPENVDB_INSTANTIATE_STRUCT:&#160;version.h.in'],['../ExplicitInstantiation_8h.html#a16997c6054e446cc8ed613c9b027522d',1,'OPENVDB_INSTANTIATE_STRUCT:&#160;ExplicitInstantiation.h']]],
   ['openvdb_5fis_5fpod_22',['OPENVDB_IS_POD',['../Math_8h.html#a76e004807bfa2a68739ea66b5f88c3ba',1,'Math.h']]],
   ['openvdb_5flibrary_5fabi_5fversion_5fstring_23',['OPENVDB_LIBRARY_ABI_VERSION_STRING',['../version_8h_8in.html#a272bfcd1c61e4da085256e85e3af8dc8',1,'version.h.in']]],
   ['openvdb_5flibrary_5fmajor_5fversion_5fnumber_24',['OPENVDB_LIBRARY_MAJOR_VERSION_NUMBER',['../version_8h_8in.html#ab04cca0a808617a2145460fc13d77534',1,'version.h.in']]],
@@ -36,17 +36,17 @@ var searchData=
   ['openvdb_5flog_5ffatal_33',['OPENVDB_LOG_FATAL',['../logging_8h.html#a743e36b29932fefe6fd87519d85fdce2',1,'logging.h']]],
   ['openvdb_5flog_5finfo_34',['OPENVDB_LOG_INFO',['../logging_8h.html#a613aa93b2e98f1b56e66f731bf6928ec',1,'logging.h']]],
   ['openvdb_5flog_5fwarn_35',['OPENVDB_LOG_WARN',['../logging_8h.html#a5a55a6912fba67df50a02fd549bea63f',1,'logging.h']]],
-  ['openvdb_5fmap_5fclass_5fspecifier_36',['OPENVDB_MAP_CLASS_SPECIFIER',['../Maps_8h.html#a8e1ef07ef31d80ba2fb5349e2affa81d',1,'Maps.h']]],
-  ['openvdb_5fmap_5ffunc_5fspecifier_37',['OPENVDB_MAP_FUNC_SPECIFIER',['../Maps_8h.html#ae9e6ac8c6ea58bc79db3aa457bbf7763',1,'Maps.h']]],
-  ['openvdb_5fno_5fdeprecation_5fwarning_5fbegin_38',['OPENVDB_NO_DEPRECATION_WARNING_BEGIN',['../Platform_8h.html#a6cc94924e47acd6586e2f5e6c3330768',1,'Platform.h']]],
-  ['openvdb_5fno_5fdeprecation_5fwarning_5fend_39',['OPENVDB_NO_DEPRECATION_WARNING_END',['../Platform_8h.html#a0c70c8f354f37e782bf75458027eaeca',1,'Platform.h']]],
-  ['openvdb_5fno_5ffp_5fequality_5fwarning_5fbegin_40',['OPENVDB_NO_FP_EQUALITY_WARNING_BEGIN',['../Math_8h.html#aa07e40c3d7f010bcb5c1369f6a78c8b0',1,'Math.h']]],
-  ['openvdb_5fno_5ffp_5fequality_5fwarning_5fend_41',['OPENVDB_NO_FP_EQUALITY_WARNING_END',['../Math_8h.html#a97049404e8b5906163c092580a6d394a',1,'Math.h']]],
-  ['openvdb_5fno_5ftype_5fconversion_5fwarning_5fbegin_42',['OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN',['../Platform_8h.html#a4f7375e7791cade4ae486a8ebb68056f',1,'Platform.h']]],
-  ['openvdb_5fno_5ftype_5fconversion_5fwarning_5fend_43',['OPENVDB_NO_TYPE_CONVERSION_WARNING_END',['../Platform_8h.html#ac13c11880cf8b8dd311a72e5a05b295d',1,'Platform.h']]],
-  ['openvdb_5fno_5funreachable_5fcode_5fwarning_5fbegin_44',['OPENVDB_NO_UNREACHABLE_CODE_WARNING_BEGIN',['../Platform_8h.html#ac8dadf7b858eb1987194e570f80bff79',1,'Platform.h']]],
-  ['openvdb_5fno_5funreachable_5fcode_5fwarning_5fend_45',['OPENVDB_NO_UNREACHABLE_CODE_WARNING_END',['../Platform_8h.html#aa4a2916120921a779c15e6182c8d8118',1,'Platform.h']]],
-  ['openvdb_5fnumeric_5ftree_5finstantiate_46',['OPENVDB_NUMERIC_TREE_INSTANTIATE',['../version_8h_8in.html#a392f57a6af5cdf543083e2b34652763c',1,'version.h.in']]],
+  ['openvdb_5fno_5fdeprecation_5fwarning_5fbegin_36',['OPENVDB_NO_DEPRECATION_WARNING_BEGIN',['../Platform_8h.html#a6cc94924e47acd6586e2f5e6c3330768',1,'Platform.h']]],
+  ['openvdb_5fno_5fdeprecation_5fwarning_5fend_37',['OPENVDB_NO_DEPRECATION_WARNING_END',['../Platform_8h.html#a0c70c8f354f37e782bf75458027eaeca',1,'Platform.h']]],
+  ['openvdb_5fno_5ffp_5fequality_5fwarning_5fbegin_38',['OPENVDB_NO_FP_EQUALITY_WARNING_BEGIN',['../Math_8h.html#aa07e40c3d7f010bcb5c1369f6a78c8b0',1,'Math.h']]],
+  ['openvdb_5fno_5ffp_5fequality_5fwarning_5fend_39',['OPENVDB_NO_FP_EQUALITY_WARNING_END',['../Math_8h.html#a97049404e8b5906163c092580a6d394a',1,'Math.h']]],
+  ['openvdb_5fno_5ftype_5fconversion_5fwarning_5fbegin_40',['OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN',['../Platform_8h.html#a4f7375e7791cade4ae486a8ebb68056f',1,'Platform.h']]],
+  ['openvdb_5fno_5ftype_5fconversion_5fwarning_5fend_41',['OPENVDB_NO_TYPE_CONVERSION_WARNING_END',['../Platform_8h.html#ac13c11880cf8b8dd311a72e5a05b295d',1,'Platform.h']]],
+  ['openvdb_5fno_5funreachable_5fcode_5fwarning_5fbegin_42',['OPENVDB_NO_UNREACHABLE_CODE_WARNING_BEGIN',['../Platform_8h.html#ac8dadf7b858eb1987194e570f80bff79',1,'Platform.h']]],
+  ['openvdb_5fno_5funreachable_5fcode_5fwarning_5fend_43',['OPENVDB_NO_UNREACHABLE_CODE_WARNING_END',['../Platform_8h.html#aa4a2916120921a779c15e6182c8d8118',1,'Platform.h']]],
+  ['openvdb_5fnumeric_5ftree_5finstantiate_44',['OPENVDB_NUMERIC_TREE_INSTANTIATE',['../version_8h_8in.html#a392f57a6af5cdf543083e2b34652763c',1,'version.h.in']]],
+  ['openvdb_5fpackage_5frevision_45',['OPENVDB_PACKAGE_REVISION',['../version_8h_8in.html#a45d92b7b2794bdecd50c965b7b7b0431',1,'version.h.in']]],
+  ['openvdb_5fpackage_5furl_46',['OPENVDB_PACKAGE_URL',['../version_8h_8in.html#a793527036c5dff66a22d69059c129349',1,'version.h.in']]],
   ['openvdb_5fpreproc_5fconcat_47',['OPENVDB_PREPROC_CONCAT',['../Platform_8h.html#aa36b3655c9a79f24e58ec8b8f73cae65',1,'Platform.h']]],
   ['openvdb_5fpreproc_5fstringify_48',['OPENVDB_PREPROC_STRINGIFY',['../Platform_8h.html#a2a4ca104e8d5858d3ca984fe99f2b1df',1,'Platform.h']]],
   ['openvdb_5freal_5ftree_5finstantiate_49',['OPENVDB_REAL_TREE_INSTANTIATE',['../version_8h_8in.html#a5ab371d0dbfa33fb93da47de4fbbb780',1,'version.h.in']]],
@@ -63,13 +63,15 @@ var searchData=
   ['openvdb_5fthreadsafe_5fstatic_5freference_60',['OPENVDB_THREADSAFE_STATIC_REFERENCE',['../Platform_8h.html#af45bfee6bdac4fd25ebba777d6ae8609',1,'Platform.h']]],
   ['openvdb_5fthreadsafe_5fstatic_5fwrite_61',['OPENVDB_THREADSAFE_STATIC_WRITE',['../Platform_8h.html#a74544cfe36b32ed0637ff78e5b26e19e',1,'Platform.h']]],
   ['openvdb_5fthrow_62',['OPENVDB_THROW',['../openvdb_2Exceptions_8h.html#a3eec2ef3138c64fc5844490187c1b8d1',1,'Exceptions.h']]],
-  ['openvdb_5fuse_5fblosc_63',['OPENVDB_USE_BLOSC',['../version_8h_8in.html#ad9b4094c98dfe2c5e327e97640573397',1,'version.h.in']]],
-  ['openvdb_5fuse_5fexplicit_5finstantiation_64',['OPENVDB_USE_EXPLICIT_INSTANTIATION',['../version_8h_8in.html#a9ae309f5f7e4f0e48703fdf3fd0a1df1',1,'version.h.in']]],
-  ['openvdb_5fuse_5fimath_5fhalf_65',['OPENVDB_USE_IMATH_HALF',['../version_8h_8in.html#afd09230e7f8a44c7b990c2d64326b6d5',1,'version.h.in']]],
-  ['openvdb_5fuse_5fversion_5fnamespace_66',['OPENVDB_USE_VERSION_NAMESPACE',['../version_8h_8in.html#a2dde157791cd7558cdf886489256ba14',1,'version.h.in']]],
-  ['openvdb_5fuse_5fzlib_67',['OPENVDB_USE_ZLIB',['../version_8h_8in.html#a729c4c59a11263debb7250fd2646315c',1,'version.h.in']]],
-  ['openvdb_5fvec3_5ftree_5finstantiate_68',['OPENVDB_VEC3_TREE_INSTANTIATE',['../version_8h_8in.html#a7d027e8f99ea64bd389bf3015fe6eada',1,'version.h.in']]],
-  ['openvdb_5fversion_5fhas_5fbeen_5fincluded_69',['OPENVDB_VERSION_HAS_BEEN_INCLUDED',['../version_8h_8in.html#adcaf61d21377593c0e9dad4a0206bb97',1,'version.h.in']]],
-  ['openvdb_5fversion_5fname_70',['OPENVDB_VERSION_NAME',['../version_8h_8in.html#a00be3835cb8ad1ded8abd821fad20fc0',1,'version.h.in']]],
-  ['openvdb_5fvolume_5ftree_5finstantiate_71',['OPENVDB_VOLUME_TREE_INSTANTIATE',['../version_8h_8in.html#a9ae6309f0451d550fc854cf97c4b4221',1,'version.h.in']]]
+  ['openvdb_5fubsan_5fsuppress_63',['OPENVDB_UBSAN_SUPPRESS',['../Platform_8h.html#a75f69f6aab6d38a8269686d79b268b29',1,'Platform.h']]],
+  ['openvdb_5fuse_5fblosc_64',['OPENVDB_USE_BLOSC',['../version_8h_8in.html#ad9b4094c98dfe2c5e327e97640573397',1,'version.h.in']]],
+  ['openvdb_5fuse_5fdelayed_5floading_65',['OPENVDB_USE_DELAYED_LOADING',['../version_8h_8in.html#a37848ce33ebef26696a36d9975a1fe1a',1,'version.h.in']]],
+  ['openvdb_5fuse_5fexplicit_5finstantiation_66',['OPENVDB_USE_EXPLICIT_INSTANTIATION',['../version_8h_8in.html#a9ae309f5f7e4f0e48703fdf3fd0a1df1',1,'version.h.in']]],
+  ['openvdb_5fuse_5fimath_5fhalf_67',['OPENVDB_USE_IMATH_HALF',['../version_8h_8in.html#afd09230e7f8a44c7b990c2d64326b6d5',1,'version.h.in']]],
+  ['openvdb_5fuse_5fversion_5fnamespace_68',['OPENVDB_USE_VERSION_NAMESPACE',['../version_8h_8in.html#a2dde157791cd7558cdf886489256ba14',1,'version.h.in']]],
+  ['openvdb_5fuse_5fzlib_69',['OPENVDB_USE_ZLIB',['../version_8h_8in.html#a729c4c59a11263debb7250fd2646315c',1,'version.h.in']]],
+  ['openvdb_5fvec3_5ftree_5finstantiate_70',['OPENVDB_VEC3_TREE_INSTANTIATE',['../version_8h_8in.html#a7d027e8f99ea64bd389bf3015fe6eada',1,'version.h.in']]],
+  ['openvdb_5fversion_5fhas_5fbeen_5fincluded_71',['OPENVDB_VERSION_HAS_BEEN_INCLUDED',['../version_8h_8in.html#adcaf61d21377593c0e9dad4a0206bb97',1,'version.h.in']]],
+  ['openvdb_5fversion_5fname_72',['OPENVDB_VERSION_NAME',['../version_8h_8in.html#a00be3835cb8ad1ded8abd821fad20fc0',1,'version.h.in']]],
+  ['openvdb_5fvolume_5ftree_5finstantiate_73',['OPENVDB_VOLUME_TREE_INSTANTIATE',['../version_8h_8in.html#a9ae6309f0451d550fc854cf97c4b4221',1,'version.h.in']]]
 ];
