@@ -2,7 +2,7 @@ var searchData=
 [
   ['gridblinddataclass_0',['GridBlindDataClass',['../namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757',1,'nanovdb']]],
   ['gridblinddatasemantic_1',['GridBlindDataSemantic',['../namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1ea',1,'nanovdb']]],
-  ['gridclass_2',['GridClass',['../namespaceopenvdb_1_1v9__0.html#a511a7f5bd868162ec06bcc20b98e160e',1,'openvdb::v9_0::GridClass()'],['../namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538',1,'nanovdb::GridClass()']]],
+  ['gridclass_2',['gridclass',['../namespaceopenvdb_1_1v10__0.html#a511a7f5bd868162ec06bcc20b98e160e',1,'openvdb::v10_0::GridClass'],['../namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538',1,'nanovdb::GridClass']]],
   ['gridflags_3',['GridFlags',['../namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2',1,'nanovdb']]],
   ['gridtype_4',['GridType',['../namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0',1,'nanovdb']]]
 ];
